==> centreon-web-23.04.26.tar.gz: centreon-web-23.04.26/packages/ui/src/Module/LicensedModule/LicenseCheck/index.tsx <==
import * as React from 'react';

import { isNil } from 'ramda';
import { useTranslation } from 'react-i18next';

import { FallbackPage } from '../../../FallbackPage/FallbackPage';
import { PageSkeleton, useFetchQuery } from '../../..';
import { getModuleLicenseCheckEndpoint } from '../api';

import { licenseDecoder } from './decoder';
import { License } from './models';
import {
  labelContactYourAdministrator,
  labelInvalidLicense,
  labelOops
} from './translatedLabels';

export interface LicenseCheckProps {
  children: React.ReactElement;
  moduleName: string;
}

interface ContentProps {
  children: React.ReactElement;
  isValid: boolean;
}

const Content = ({ children, isValid }: ContentProps): JSX.Element => {
  const { t } = useTranslation();

  return isValid ? (
    children
  ) : (
    <FallbackPage
      contactAdmin={t(labelContactYourAdministrator) || ''}
      message={t(labelInvalidLicense) || ''}
      title={t(labelOops) || ''}
    />
  );
};

const LicenseCheck = ({
  children,
  moduleName
}: LicenseCheckProps): JSX.Element | null => {
  const { isError, data } = useFetchQuery<License>({
    decoder: licenseDecoder,
    getEndpoint: () => getModuleLicenseCheckEndpoint(moduleName),
    getQueryKey: () => ['license', moduleName]
  });

  if (isError) {
    return null;
  }

  const isValid = data?.success;

  return isNil(isValid) ? (
    <PageSkeleton />
  ) : (
    <Content isValid={isValid as boolean}>{children}</Content>
  );
};

export default LicenseCheck;

==> centreon-web-24.04.12.tar.gz: centreon-web-24.04.12/packages/ui/src/Module/LicensedModule/LicenseCheck/index.tsx <==
import { useTranslation } from 'react-i18next';

import { FallbackPage } from '../../../FallbackPage/FallbackPage';
import { MenuSkeleton, PageSkeleton, useFetchQuery } from '../../..';
import { getModuleLicenseCheckEndpoint } from '../api';

import { licenseDecoder } from './decoder';
import { License } from './models';
import {
  labelContactYourAdministrator,
  labelInvalidLicense,
  labelOops
} from './translatedLabels';

export interface LicenseCheckProps {
  children: React.ReactElement;
  isFederatedComponent?: boolean;
  moduleName: string;
}

interface ContentProps {
  children: React.ReactElement;
  isFederatedComponent?: boolean;
  isValid: boolean;
}

const Content = ({
  children,
  isValid,
  isFederatedComponent
}: ContentProps): JSX.Element | null => {
  const { t } = useTranslation();

  if (isFederatedComponent && !isValid) {
    return null;
  }

  return isValid ? (
    children
  ) : (
    <FallbackPage
      contactAdmin={t(labelContactYourAdministrator) || ''}
      message={t(labelInvalidLicense) || ''}
      title={t(labelOops) || ''}
    />
  );
};

const LicenseCheck = ({
  isFederatedComponent,
  children,
  moduleName
}: LicenseCheckProps): JSX.Element | null => {
  const { isError, data, isLoading } = useFetchQuery<License>({
    decoder: licenseDecoder,
    getEndpoint: () => getModuleLicenseCheckEndpoint(moduleName),
    getQueryKey: () => ['license', moduleName]
  });

  if (isError) {
    return null;
  }

  const isValid = data?.success;

  const skeleton = isFederatedComponent ? <MenuSkeleton /> : <PageSkeleton />;

  return isLoading ? (
    skeleton
  ) : (
    <Content
      isFederatedComponent={isFederatedComponent}
      isValid={isValid as boolean}
    >
      {children}
    </Content>
  );
};

export default LicenseCheck;
